@@ -1,5 +1,5 @@
 /* eslint no-var: 0 */
-var main = require('./dist/commonjs/index.js').default;
+var main = require('./dist/cjs/i18nextBrowserLanguageDetector.js');
 
 module.exports = main;
-module.exports.default = main;
+module.exports.default = main;
\ No newline at end of file
